"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import google.protobuf.timestamp_pb2
import sys
import typing
import yandex.cloud.organizationmanager.v1.idp.synchronization_settings_pb2

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class _OpenSessionResult:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _OpenSessionResultEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_OpenSessionResult.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    OPEN_SESSION_RESULT_UNSPECIFIED: _OpenSessionResult.ValueType  # 0
    """The result is not specified."""
    SUCCESS: _OpenSessionResult.ValueType  # 1
    """Session opened successfully."""
    OPENED_SESSION_EXISTS: _OpenSessionResult.ValueType  # 2
    """A session already exists."""
    TOO_EARLY: _OpenSessionResult.ValueType  # 3
    """Too early to open a new session."""

class OpenSessionResult(_OpenSessionResult, metaclass=_OpenSessionResultEnumTypeWrapper):
    """Result of opening a synchronization session."""

OPEN_SESSION_RESULT_UNSPECIFIED: OpenSessionResult.ValueType  # 0
"""The result is not specified."""
SUCCESS: OpenSessionResult.ValueType  # 1
"""Session opened successfully."""
OPENED_SESSION_EXISTS: OpenSessionResult.ValueType  # 2
"""A session already exists."""
TOO_EARLY: OpenSessionResult.ValueType  # 3
"""Too early to open a new session."""
global___OpenSessionResult = OpenSessionResult

class _ChangeType:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _ChangeTypeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_ChangeType.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    CHANGE_TYPE_UNSPECIFIED: _ChangeType.ValueType  # 0
    """The change type is not specified."""
    CREATE: _ChangeType.ValueType  # 1
    """Create operation."""
    UPDATE: _ChangeType.ValueType  # 2
    """Update operation."""
    DELETE: _ChangeType.ValueType  # 3
    """Delete operation."""
    ACTIVATE: _ChangeType.ValueType  # 4
    """Activate operation."""
    DEACTIVATE: _ChangeType.ValueType  # 5
    """Deactivate operation."""
    PASSWORD_HASH_UPDATE: _ChangeType.ValueType  # 6
    """Password hash update operation."""

class ChangeType(_ChangeType, metaclass=_ChangeTypeEnumTypeWrapper):
    """Type of change during synchronization."""

CHANGE_TYPE_UNSPECIFIED: ChangeType.ValueType  # 0
"""The change type is not specified."""
CREATE: ChangeType.ValueType  # 1
"""Create operation."""
UPDATE: ChangeType.ValueType  # 2
"""Update operation."""
DELETE: ChangeType.ValueType  # 3
"""Delete operation."""
ACTIVATE: ChangeType.ValueType  # 4
"""Activate operation."""
DEACTIVATE: ChangeType.ValueType  # 5
"""Deactivate operation."""
PASSWORD_HASH_UPDATE: ChangeType.ValueType  # 6
"""Password hash update operation."""
global___ChangeType = ChangeType

class _RelatedObjectType:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _RelatedObjectTypeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_RelatedObjectType.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    RELATED_OBJECT_TYPE_UNSPECIFIED: _RelatedObjectType.ValueType  # 0
    """The object type is not specified."""
    USER: _RelatedObjectType.ValueType  # 1
    """User object."""
    GROUP: _RelatedObjectType.ValueType  # 2
    """Group object."""
    MEMBERSHIP: _RelatedObjectType.ValueType  # 3
    """Membership object."""

class RelatedObjectType(_RelatedObjectType, metaclass=_RelatedObjectTypeEnumTypeWrapper):
    """Type of object related to synchronization."""

RELATED_OBJECT_TYPE_UNSPECIFIED: RelatedObjectType.ValueType  # 0
"""The object type is not specified."""
USER: RelatedObjectType.ValueType  # 1
"""User object."""
GROUP: RelatedObjectType.ValueType  # 2
"""Group object."""
MEMBERSHIP: RelatedObjectType.ValueType  # 3
"""Membership object."""
global___RelatedObjectType = RelatedObjectType

class _SyncMode:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _SyncModeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_SyncMode.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    SYNC_MODE_UNSPECIFIED: _SyncMode.ValueType  # 0
    """The sync mode is not specified."""
    FULL_SYNC: _SyncMode.ValueType  # 1
    """Full synchronization mode."""
    DELTA: _SyncMode.ValueType  # 2
    """Delta synchronization mode."""

class SyncMode(_SyncMode, metaclass=_SyncModeEnumTypeWrapper):
    """Synchronization mode."""

SYNC_MODE_UNSPECIFIED: SyncMode.ValueType  # 0
"""The sync mode is not specified."""
FULL_SYNC: SyncMode.ValueType  # 1
"""Full synchronization mode."""
DELTA: SyncMode.ValueType  # 2
"""Delta synchronization mode."""
global___SyncMode = SyncMode

class _SessionStatus:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _SessionStatusEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_SessionStatus.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    SESSION_STATUS_UNSPECIFIED: _SessionStatus.ValueType  # 0
    """The status is not specified."""
    OPENED: _SessionStatus.ValueType  # 1
    """Session is opened."""
    PENDING: _SessionStatus.ValueType  # 2
    """Session is pending."""
    COMPLETED: _SessionStatus.ValueType  # 3
    """Session is completed."""
    FAILED: _SessionStatus.ValueType  # 4
    """Session has failed."""
    EXPIRED: _SessionStatus.ValueType  # 5
    """Session has expired."""

class SessionStatus(_SessionStatus, metaclass=_SessionStatusEnumTypeWrapper):
    """Status of a synchronization session."""

SESSION_STATUS_UNSPECIFIED: SessionStatus.ValueType  # 0
"""The status is not specified."""
OPENED: SessionStatus.ValueType  # 1
"""Session is opened."""
PENDING: SessionStatus.ValueType  # 2
"""Session is pending."""
COMPLETED: SessionStatus.ValueType  # 3
"""Session is completed."""
FAILED: SessionStatus.ValueType  # 4
"""Session has failed."""
EXPIRED: SessionStatus.ValueType  # 5
"""Session has expired."""
global___SessionStatus = SessionStatus

@typing.final
class OpenSessionRequest(google.protobuf.message.Message):
    """Request to open a synchronization session."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SUBJECT_CONTAINER_ID_FIELD_NUMBER: builtins.int
    AGENT_ID_FIELD_NUMBER: builtins.int
    SESSION_TYPE_FIELD_NUMBER: builtins.int
    subject_container_id: builtins.str
    """ID of the subject container."""
    agent_id: builtins.str
    """ID of the agent opening the session."""
    session_type: yandex.cloud.organizationmanager.v1.idp.synchronization_settings_pb2.SessionType.ValueType
    """Type of synchronization session."""
    def __init__(
        self,
        *,
        subject_container_id: builtins.str = ...,
        agent_id: builtins.str = ...,
        session_type: yandex.cloud.organizationmanager.v1.idp.synchronization_settings_pb2.SessionType.ValueType = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["agent_id", b"agent_id", "session_type", b"session_type", "subject_container_id", b"subject_container_id"]) -> None: ...

global___OpenSessionRequest = OpenSessionRequest

@typing.final
class SynchronizationSession(google.protobuf.message.Message):
    """Synchronization session information."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SESSION_ID_FIELD_NUMBER: builtins.int
    AGENT_ID_FIELD_NUMBER: builtins.int
    CREATED_AT_FIELD_NUMBER: builtins.int
    EXPIRES_AT_FIELD_NUMBER: builtins.int
    CLOSED_AT_FIELD_NUMBER: builtins.int
    SYNC_MODE_FIELD_NUMBER: builtins.int
    STATUS_FIELD_NUMBER: builtins.int
    PROGRESS_ENTRIES_FIELD_NUMBER: builtins.int
    FAIL_REASON_FIELD_NUMBER: builtins.int
    SESSION_TYPE_FIELD_NUMBER: builtins.int
    session_id: builtins.str
    """Unique identifier of the session."""
    agent_id: builtins.str
    """ID of the agent managing the session."""
    sync_mode: global___SyncMode.ValueType
    """Synchronization mode."""
    status: global___SessionStatus.ValueType
    """Current status of the session."""
    fail_reason: builtins.str
    """Reason for session failure, if any."""
    session_type: yandex.cloud.organizationmanager.v1.idp.synchronization_settings_pb2.SessionType.ValueType
    """Type of synchronization session."""
    @property
    def created_at(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """Timestamp when the session was created."""

    @property
    def expires_at(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """Timestamp when the session expires."""

    @property
    def closed_at(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """Timestamp when the session was closed."""

    @property
    def progress_entries(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ProgressEntry]:
        """List of progress entries."""

    def __init__(
        self,
        *,
        session_id: builtins.str = ...,
        agent_id: builtins.str = ...,
        created_at: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        expires_at: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        closed_at: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        sync_mode: global___SyncMode.ValueType = ...,
        status: global___SessionStatus.ValueType = ...,
        progress_entries: collections.abc.Iterable[global___ProgressEntry] | None = ...,
        fail_reason: builtins.str = ...,
        session_type: yandex.cloud.organizationmanager.v1.idp.synchronization_settings_pb2.SessionType.ValueType = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["closed_at", b"closed_at", "created_at", b"created_at", "expires_at", b"expires_at"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["agent_id", b"agent_id", "closed_at", b"closed_at", "created_at", b"created_at", "expires_at", b"expires_at", "fail_reason", b"fail_reason", "progress_entries", b"progress_entries", "session_id", b"session_id", "session_type", b"session_type", "status", b"status", "sync_mode", b"sync_mode"]) -> None: ...

global___SynchronizationSession = SynchronizationSession

@typing.final
class OpenSessionResponse(google.protobuf.message.Message):
    """Response message for [SynchronizationSessionService.OpenSession]."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESULT_FIELD_NUMBER: builtins.int
    OPENED_SESSION_FIELD_NUMBER: builtins.int
    NEXT_SESSION_AT_FIELD_NUMBER: builtins.int
    REPLICATION_TOKEN_FIELD_NUMBER: builtins.int
    SYNCHRONIZATION_SETTINGS_FIELD_NUMBER: builtins.int
    result: global___OpenSessionResult.ValueType
    """Result of opening the session."""
    replication_token: builtins.str
    """Replication token for the session."""
    @property
    def opened_session(self) -> global___SynchronizationSession:
        """Opened session information."""

    @property
    def next_session_at(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """Timestamp for the next session if too early."""

    @property
    def synchronization_settings(self) -> yandex.cloud.organizationmanager.v1.idp.synchronization_settings_pb2.SynchronizationSettings:
        """Synchronization settings for the session."""

    def __init__(
        self,
        *,
        result: global___OpenSessionResult.ValueType = ...,
        opened_session: global___SynchronizationSession | None = ...,
        next_session_at: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        replication_token: builtins.str = ...,
        synchronization_settings: yandex.cloud.organizationmanager.v1.idp.synchronization_settings_pb2.SynchronizationSettings | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["next_session_at", b"next_session_at", "opened_session", b"opened_session", "session_info", b"session_info", "synchronization_settings", b"synchronization_settings"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["next_session_at", b"next_session_at", "opened_session", b"opened_session", "replication_token", b"replication_token", "result", b"result", "session_info", b"session_info", "synchronization_settings", b"synchronization_settings"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["session_info", b"session_info"]) -> typing.Literal["opened_session", "next_session_at"] | None: ...

global___OpenSessionResponse = OpenSessionResponse

@typing.final
class OpenSessionMetadata(google.protobuf.message.Message):
    """Metadata for the [SynchronizationSessionService.OpenSession] operation."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SESSION_ID_FIELD_NUMBER: builtins.int
    session_id: builtins.str
    """ID of the session."""
    def __init__(
        self,
        *,
        session_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["session_id", b"session_id"]) -> None: ...

global___OpenSessionMetadata = OpenSessionMetadata

@typing.final
class GetSessionRequest(google.protobuf.message.Message):
    """Request to get a synchronization session."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SESSION_ID_FIELD_NUMBER: builtins.int
    session_id: builtins.str
    """ID of the session to return."""
    def __init__(
        self,
        *,
        session_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["session_id", b"session_id"]) -> None: ...

global___GetSessionRequest = GetSessionRequest

@typing.final
class GetSessionResponse(google.protobuf.message.Message):
    """Response message for [SynchronizationSessionService.GetSession]."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SESSION_FIELD_NUMBER: builtins.int
    @property
    def session(self) -> global___SynchronizationSession:
        """Synchronization session information."""

    def __init__(
        self,
        *,
        session: global___SynchronizationSession | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["session", b"session"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["session", b"session"]) -> None: ...

global___GetSessionResponse = GetSessionResponse

@typing.final
class ReportSessionProgressRequest(google.protobuf.message.Message):
    """Request to report session progress."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SESSION_ID_FIELD_NUMBER: builtins.int
    PROGRESS_ENTRIES_FIELD_NUMBER: builtins.int
    session_id: builtins.str
    """ID of the session."""
    @property
    def progress_entries(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ProgressEntry]:
        """List of progress entries."""

    def __init__(
        self,
        *,
        session_id: builtins.str = ...,
        progress_entries: collections.abc.Iterable[global___ProgressEntry] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["progress_entries", b"progress_entries", "session_id", b"session_id"]) -> None: ...

global___ReportSessionProgressRequest = ReportSessionProgressRequest

@typing.final
class ReportSessionProgressMetadata(google.protobuf.message.Message):
    """Metadata for the [SynchronizationSessionService.ReportSessionProgress] operation."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SESSION_ID_FIELD_NUMBER: builtins.int
    session_id: builtins.str
    """ID of the session."""
    def __init__(
        self,
        *,
        session_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["session_id", b"session_id"]) -> None: ...

global___ReportSessionProgressMetadata = ReportSessionProgressMetadata

@typing.final
class ProgressEntry(google.protobuf.message.Message):
    """Progress entry for synchronization."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    OBJECT_TYPE_FIELD_NUMBER: builtins.int
    CHANGE_INFO_FIELD_NUMBER: builtins.int
    object_type: global___RelatedObjectType.ValueType
    """Type of object being synchronized."""
    @property
    def change_info(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ChangeInfo]:
        """List of change information."""

    def __init__(
        self,
        *,
        object_type: global___RelatedObjectType.ValueType = ...,
        change_info: collections.abc.Iterable[global___ChangeInfo] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["change_info", b"change_info", "object_type", b"object_type"]) -> None: ...

global___ProgressEntry = ProgressEntry

@typing.final
class ChangeInfo(google.protobuf.message.Message):
    """Information about changes during synchronization."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CHANGE_TYPE_FIELD_NUMBER: builtins.int
    SUCCESSFUL_FIELD_NUMBER: builtins.int
    FAILED_FIELD_NUMBER: builtins.int
    change_type: global___ChangeType.ValueType
    """Type of change."""
    successful: builtins.int
    """Number of successful changes."""
    failed: builtins.int
    """Number of failed changes."""
    def __init__(
        self,
        *,
        change_type: global___ChangeType.ValueType = ...,
        successful: builtins.int = ...,
        failed: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["change_type", b"change_type", "failed", b"failed", "successful", b"successful"]) -> None: ...

global___ChangeInfo = ChangeInfo

@typing.final
class ListSessionsRequest(google.protobuf.message.Message):
    """Request to list synchronization sessions."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SUBJECT_CONTAINER_ID_FIELD_NUMBER: builtins.int
    PAGE_SIZE_FIELD_NUMBER: builtins.int
    PAGE_TOKEN_FIELD_NUMBER: builtins.int
    FILTER_FIELD_NUMBER: builtins.int
    subject_container_id: builtins.str
    """ID of the subject container."""
    page_size: builtins.int
    """The maximum number of results per page to return."""
    page_token: builtins.str
    """Page token for pagination."""
    filter: builtins.str
    """A filter expression that filters resources listed in the response."""
    def __init__(
        self,
        *,
        subject_container_id: builtins.str = ...,
        page_size: builtins.int = ...,
        page_token: builtins.str = ...,
        filter: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["filter", b"filter", "page_size", b"page_size", "page_token", b"page_token", "subject_container_id", b"subject_container_id"]) -> None: ...

global___ListSessionsRequest = ListSessionsRequest

@typing.final
class ListSessionsResponse(google.protobuf.message.Message):
    """Response message for [SynchronizationSessionService.ListSessions]."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SESSIONS_FIELD_NUMBER: builtins.int
    NEXT_PAGE_TOKEN_FIELD_NUMBER: builtins.int
    next_page_token: builtins.str
    """Token for getting the next page of the list."""
    @property
    def sessions(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___SynchronizationSession]:
        """List of synchronization sessions."""

    def __init__(
        self,
        *,
        sessions: collections.abc.Iterable[global___SynchronizationSession] | None = ...,
        next_page_token: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["next_page_token", b"next_page_token", "sessions", b"sessions"]) -> None: ...

global___ListSessionsResponse = ListSessionsResponse

@typing.final
class CloseSessionRequest(google.protobuf.message.Message):
    """Request to close a synchronization session."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SESSION_ID_FIELD_NUMBER: builtins.int
    FAILED_FIELD_NUMBER: builtins.int
    FAIL_REASON_FIELD_NUMBER: builtins.int
    session_id: builtins.str
    """ID of the session to close."""
    failed: builtins.bool
    """Whether the session failed."""
    fail_reason: builtins.str
    """Reason for session failure, if any."""
    def __init__(
        self,
        *,
        session_id: builtins.str = ...,
        failed: builtins.bool = ...,
        fail_reason: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["fail_reason", b"fail_reason", "failed", b"failed", "session_id", b"session_id"]) -> None: ...

global___CloseSessionRequest = CloseSessionRequest

@typing.final
class CloseSessionMetadata(google.protobuf.message.Message):
    """Metadata for the [SynchronizationSessionService.CloseSession] operation."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SESSION_ID_FIELD_NUMBER: builtins.int
    session_id: builtins.str
    """ID of the session."""
    def __init__(
        self,
        *,
        session_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["session_id", b"session_id"]) -> None: ...

global___CloseSessionMetadata = CloseSessionMetadata

@typing.final
class HeartbeatRequest(google.protobuf.message.Message):
    """Request to send a heartbeat for a synchronization session."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SESSION_ID_FIELD_NUMBER: builtins.int
    session_id: builtins.str
    """ID of the session."""
    def __init__(
        self,
        *,
        session_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["session_id", b"session_id"]) -> None: ...

global___HeartbeatRequest = HeartbeatRequest

@typing.final
class HeartbeatMetadata(google.protobuf.message.Message):
    """Metadata for the [SynchronizationSessionService.Heartbeat] operation."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SESSION_ID_FIELD_NUMBER: builtins.int
    session_id: builtins.str
    """ID of the session."""
    def __init__(
        self,
        *,
        session_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["session_id", b"session_id"]) -> None: ...

global___HeartbeatMetadata = HeartbeatMetadata



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import abc
import collections.abc
import grpc
import grpc.aio
import typing
import yandex.cloud.iam.v1.access_analyzer_service_pb2

_T = typing.TypeVar("_T")

class _MaybeAsyncIterator(collections.abc.AsyncIterator[_T], collections.abc.Iterator[_T], metaclass=abc.ABCMeta): ...

class _ServicerContext(grpc.ServicerContext, grpc.aio.ServicerContext):  # type: ignore[misc, type-arg]
    ...

class AccessAnalyzerServiceStub:
    """A set of methods for access analysis."""

    def __init__(self, channel: typing.Union[grpc.Channel, grpc.aio.Channel]) -> None: ...
    ListSubjectAccessBindings: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.iam.v1.access_analyzer_service_pb2.ListSubjectAccessBindingsRequest,
        yandex.cloud.iam.v1.access_analyzer_service_pb2.ListSubjectAccessBindingsResponse,
    ]
    """Returns the list of access bindings for the specified subject in chosen organization."""

class AccessAnalyzerServiceAsyncStub:
    """A set of methods for access analysis."""

    ListSubjectAccessBindings: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.iam.v1.access_analyzer_service_pb2.ListSubjectAccessBindingsRequest,
        yandex.cloud.iam.v1.access_analyzer_service_pb2.ListSubjectAccessBindingsResponse,
    ]
    """Returns the list of access bindings for the specified subject in chosen organization."""

class AccessAnalyzerServiceServicer(metaclass=abc.ABCMeta):
    """A set of methods for access analysis."""

    @abc.abstractmethod
    def ListSubjectAccessBindings(
        self,
        request: yandex.cloud.iam.v1.access_analyzer_service_pb2.ListSubjectAccessBindingsRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.iam.v1.access_analyzer_service_pb2.ListSubjectAccessBindingsResponse, collections.abc.Awaitable[yandex.cloud.iam.v1.access_analyzer_service_pb2.ListSubjectAccessBindingsResponse]]:
        """Returns the list of access bindings for the specified subject in chosen organization."""

def add_AccessAnalyzerServiceServicer_to_server(servicer: AccessAnalyzerServiceServicer, server: typing.Union[grpc.Server, grpc.aio.Server]) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: yandex/cloud/organizationmanager/v1/mfa_enforcement.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'yandex/cloud/organizationmanager/v1/mfa_enforcement.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n9yandex/cloud/organizationmanager/v1/mfa_enforcement.proto\x12#yandex.cloud.organizationmanager.v1\x1a\x1egoogle/protobuf/duration.proto\x1a\x1fgoogle/protobuf/timestamp.proto\"\xeb\x02\n\x0eMfaEnforcement\x12\n\n\x02id\x18\x01 \x01(\t\x12\x17\n\x0forganization_id\x18\x02 \x01(\t\x12\x0e\n\x06\x61\x63r_id\x18\x03 \x01(\t\x12&\n\x03ttl\x18\x04 \x01(\x0b\x32\x19.google.protobuf.Duration\x12I\n\x06status\x18\x05 \x01(\x0e\x32\x39.yandex.cloud.organizationmanager.v1.MfaEnforcementStatus\x12,\n\x08\x61pply_at\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x30\n\renroll_window\x18\x07 \x01(\x0b\x32\x19.google.protobuf.Duration\x12\x0c\n\x04name\x18\x08 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\t \x01(\t\x12.\n\ncreated_at\x18\n \x01(\x0b\x32\x1a.google.protobuf.Timestamp*\xab\x01\n\x14MfaEnforcementStatus\x12&\n\"MFA_ENFORCEMENT_STATUS_UNSPECIFIED\x10\x00\x12!\n\x1dMFA_ENFORCEMENT_STATUS_ACTIVE\x10\x01\x12#\n\x1fMFA_ENFORCEMENT_STATUS_INACTIVE\x10\x02\x12#\n\x1fMFA_ENFORCEMENT_STATUS_DELETING\x10\x03\x42\x86\x01\n\'yandex.cloud.api.organizationmanager.v1Z[github.com/yandex-cloud/go-genproto/yandex/cloud/organizationmanager/v1;organizationmanagerb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.organizationmanager.v1.mfa_enforcement_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\'yandex.cloud.api.organizationmanager.v1Z[github.com/yandex-cloud/go-genproto/yandex/cloud/organizationmanager/v1;organizationmanager'
  _globals['_MFAENFORCEMENTSTATUS']._serialized_start=530
  _globals['_MFAENFORCEMENTSTATUS']._serialized_end=701
  _globals['_MFAENFORCEMENT']._serialized_start=164
  _globals['_MFAENFORCEMENT']._serialized_end=527
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: yandex/cloud/marketplace/stacklandlicenseapi/v1/license_server_service.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'yandex/cloud/marketplace/stacklandlicenseapi/v1/license_server_service.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from yandex.cloud.api import operation_pb2 as yandex_dot_cloud_dot_api_dot_operation__pb2
from yandex.cloud.marketplace.stacklandlicenseapi.v1 import license_server_pb2 as yandex_dot_cloud_dot_marketplace_dot_stacklandlicenseapi_dot_v1_dot_license__server__pb2
from yandex.cloud.marketplace.stacklandlicenseapi.v1 import sync_pb2 as yandex_dot_cloud_dot_marketplace_dot_stacklandlicenseapi_dot_v1_dot_sync__pb2
from yandex.cloud.operation import operation_pb2 as yandex_dot_cloud_dot_operation_dot_operation__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nLyandex/cloud/marketplace/stacklandlicenseapi/v1/license_server_service.proto\x12/yandex.cloud.marketplace.stacklandlicenseapi.v1\x1a\x1cgoogle/api/annotations.proto\x1a yandex/cloud/api/operation.proto\x1a\x44yandex/cloud/marketplace/stacklandlicenseapi/v1/license_server.proto\x1a:yandex/cloud/marketplace/stacklandlicenseapi/v1/sync.proto\x1a&yandex/cloud/operation/operation.proto2\xde\x03\n\x14LicenseServerService\x12\xe7\x01\n\x08Register\x12@.yandex.cloud.marketplace.stacklandlicenseapi.v1.RegisterRequest\x1a!.yandex.cloud.operation.Operation\"v\xb2\xd2*.\n\x1dRegisterLicenseServerMetadata\x12\rLicenseServer\x82\xd3\xe4\x93\x02>\"9/marketplace/stackland-license/v1/licenseServers:register:\x01*\x12\xdb\x01\n\tSyncUsage\x12<.yandex.cloud.marketplace.stacklandlicenseapi.v1.SyncRequest\x1a!.yandex.cloud.operation.Operation\"m\xb2\xd2*$\n\x11SyncUsageMetadata\x12\x0fSyncUsageResult\x82\xd3\xe4\x93\x02?\":/marketplace/stackland-license/v1/licenseServers:syncUsage:\x01*B\x9e\x01\n3yandex.cloud.api.marketplace.stacklandlicenseapi.v1Zggithub.com/yandex-cloud/go-genproto/yandex/cloud/marketplace/stacklandlicenseapi/v1;stacklandlicenseapib\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.marketplace.stacklandlicenseapi.v1.license_server_service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n3yandex.cloud.api.marketplace.stacklandlicenseapi.v1Zggithub.com/yandex-cloud/go-genproto/yandex/cloud/marketplace/stacklandlicenseapi/v1;stacklandlicenseapi'
  _globals['_LICENSESERVERSERVICE'].methods_by_name['Register']._loaded_options = None
  _globals['_LICENSESERVERSERVICE'].methods_by_name['Register']._serialized_options = b'\262\322*.\n\035RegisterLicenseServerMetadata\022\rLicenseServer\202\323\344\223\002>\"9/marketplace/stackland-license/v1/licenseServers:register:\001*'
  _globals['_LICENSESERVERSERVICE'].methods_by_name['SyncUsage']._loaded_options = None
  _globals['_LICENSESERVERSERVICE'].methods_by_name['SyncUsage']._serialized_options = b'\262\322*$\n\021SyncUsageMetadata\022\017SyncUsageResult\202\323\344\223\002?\":/marketplace/stackland-license/v1/licenseServers:syncUsage:\001*'
  _globals['_LICENSESERVERSERVICE']._serialized_start=364
  _globals['_LICENSESERVERSERVICE']._serialized_end=842
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import google.protobuf.timestamp_pb2
import sys
import typing

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class Vrf(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class _Status:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _StatusEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[Vrf._Status.ValueType], builtins.type):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        STATUS_UNSPECIFIED: Vrf._Status.ValueType  # 0
        """Unspecified VRF status."""
        ACTIVE: Vrf._Status.ValueType  # 1
        """VRF is ready to use."""
        UPDATING: Vrf._Status.ValueType  # 2
        """VRF is being updated."""

    class Status(_Status, metaclass=_StatusEnumTypeWrapper): ...
    STATUS_UNSPECIFIED: Vrf.Status.ValueType  # 0
    """Unspecified VRF status."""
    ACTIVE: Vrf.Status.ValueType  # 1
    """VRF is ready to use."""
    UPDATING: Vrf.Status.ValueType  # 2
    """VRF is being updated."""

    @typing.final
    class LabelsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["key", b"key", "value", b"value"]) -> None: ...

    ID_FIELD_NUMBER: builtins.int
    CLOUD_ID_FIELD_NUMBER: builtins.int
    FOLDER_ID_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    STATUS_FIELD_NUMBER: builtins.int
    STATIC_ROUTES_FIELD_NUMBER: builtins.int
    CREATED_AT_FIELD_NUMBER: builtins.int
    LABELS_FIELD_NUMBER: builtins.int
    id: builtins.str
    """ID of the VRF."""
    cloud_id: builtins.str
    """ID of the cloud that the private subnet belongs to."""
    folder_id: builtins.str
    """ID of the folder that the private subnet belongs to."""
    name: builtins.str
    """Name of the VRF.
    The name is unique within the folder.
    """
    description: builtins.str
    """Optional description of the VRF."""
    status: global___Vrf.Status.ValueType
    """Status of the VRF."""
    @property
    def static_routes(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___StaticRoute]:
        """Static routes."""

    @property
    def created_at(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """Creation timestamp."""

    @property
    def labels(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]:
        """Resource labels as `key:value` pairs."""

    def __init__(
        self,
        *,
        id: builtins.str = ...,
        cloud_id: builtins.str = ...,
        folder_id: builtins.str = ...,
        name: builtins.str = ...,
        description: builtins.str = ...,
        status: global___Vrf.Status.ValueType = ...,
        static_routes: collections.abc.Iterable[global___StaticRoute] | None = ...,
        created_at: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        labels: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["created_at", b"created_at"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["cloud_id", b"cloud_id", "created_at", b"created_at", "description", b"description", "folder_id", b"folder_id", "id", b"id", "labels", b"labels", "name", b"name", "static_routes", b"static_routes", "status", b"status"]) -> None: ...

global___Vrf = Vrf

@typing.final
class StaticRoute(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class _RedistributionType:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _RedistributionTypeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[StaticRoute._RedistributionType.ValueType], builtins.type):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        REDISTRIBUTION_TYPE_UNSPECIFIED: StaticRoute._RedistributionType.ValueType  # 0
        """Unspecified redistribution type."""
        DISABLED: StaticRoute._RedistributionType.ValueType  # 1
        """Static route announcements outside BareMetal VRF disabled."""
        ENABLED: StaticRoute._RedistributionType.ValueType  # 2
        """Static route announcements outside BareMetal VRF enabled."""

    class RedistributionType(_RedistributionType, metaclass=_RedistributionTypeEnumTypeWrapper): ...
    REDISTRIBUTION_TYPE_UNSPECIFIED: StaticRoute.RedistributionType.ValueType  # 0
    """Unspecified redistribution type."""
    DISABLED: StaticRoute.RedistributionType.ValueType  # 1
    """Static route announcements outside BareMetal VRF disabled."""
    ENABLED: StaticRoute.RedistributionType.ValueType  # 2
    """Static route announcements outside BareMetal VRF enabled."""

    DESTINATION_CIDR_FIELD_NUMBER: builtins.int
    NEXT_HOP_IP_ADDRESS_FIELD_NUMBER: builtins.int
    REDISTRIBUTION_TYPE_FIELD_NUMBER: builtins.int
    destination_cidr: builtins.str
    """Destination network CIDR block."""
    next_hop_ip_address: builtins.str
    """Next hop host IP address."""
    redistribution_type: global___StaticRoute.RedistributionType.ValueType
    """Redistribution type."""
    def __init__(
        self,
        *,
        destination_cidr: builtins.str = ...,
        next_hop_ip_address: builtins.str = ...,
        redistribution_type: global___StaticRoute.RedistributionType.ValueType = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["destination_cidr", b"destination_cidr", "next_hop_ip_address", b"next_hop_ip_address", "redistribution_type", b"redistribution_type"]) -> None: ...

global___StaticRoute = StaticRoute



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import google.protobuf.timestamp_pb2
import sys
import typing

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class _Status:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _StatusEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_Status.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    STATUS_UNSPECIFIED: _Status.ValueType  # 0
    """The status is not specified."""
    CREATING: _Status.ValueType  # 1
    """The apllication is in the process of being created."""
    ACTIVE: _Status.ValueType  # 2
    """The apllication is active and operational."""
    SUSPENDED: _Status.ValueType  # 3
    """The apllication is suspended. I.e. authentication via this application is disabled."""
    DELETING: _Status.ValueType  # 4
    """The apllication is in the process of being deleted."""

class Status(_Status, metaclass=_StatusEnumTypeWrapper):
    """Represents the status of an application."""

STATUS_UNSPECIFIED: Status.ValueType  # 0
"""The status is not specified."""
CREATING: Status.ValueType  # 1
"""The apllication is in the process of being created."""
ACTIVE: Status.ValueType  # 2
"""The apllication is active and operational."""
SUSPENDED: Status.ValueType  # 3
"""The apllication is suspended. I.e. authentication via this application is disabled."""
DELETING: Status.ValueType  # 4
"""The apllication is in the process of being deleted."""
global___Status = Status

class _GroupDistributionType:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _GroupDistributionTypeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_GroupDistributionType.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    GROUP_DISTRIBUTION_TYPE_UNSPECIFIED: _GroupDistributionType.ValueType  # 0
    """The distribution type is unspecified"""
    NONE: _GroupDistributionType.ValueType  # 1
    """No groups are visible for the application users"""
    ASSIGNED_GROUPS: _GroupDistributionType.ValueType  # 2
    """Only assigned groups are visible for the application users"""
    ALL_GROUPS: _GroupDistributionType.ValueType  # 3
    """All groups are visible for the application users"""

class GroupDistributionType(_GroupDistributionType, metaclass=_GroupDistributionTypeEnumTypeWrapper):
    """Represents distribution type of the groups"""

GROUP_DISTRIBUTION_TYPE_UNSPECIFIED: GroupDistributionType.ValueType  # 0
"""The distribution type is unspecified"""
NONE: GroupDistributionType.ValueType  # 1
"""No groups are visible for the application users"""
ASSIGNED_GROUPS: GroupDistributionType.ValueType  # 2
"""Only assigned groups are visible for the application users"""
ALL_GROUPS: GroupDistributionType.ValueType  # 3
"""All groups are visible for the application users"""
global___GroupDistributionType = GroupDistributionType

@typing.final
class Application(google.protobuf.message.Message):
    """An OAuth application resource."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing.final
    class LabelsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["key", b"key", "value", b"value"]) -> None: ...

    ID_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    ORGANIZATION_ID_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    GROUP_CLAIMS_SETTINGS_FIELD_NUMBER: builtins.int
    CLIENT_GRANT_FIELD_NUMBER: builtins.int
    STATUS_FIELD_NUMBER: builtins.int
    LABELS_FIELD_NUMBER: builtins.int
    CREATED_AT_FIELD_NUMBER: builtins.int
    UPDATED_AT_FIELD_NUMBER: builtins.int
    id: builtins.str
    """ID of the application."""
    name: builtins.str
    """Name of the application.
    The name is unique within the organization. 3-63 characters long.
    """
    organization_id: builtins.str
    """ID of the organization that the application belongs to."""
    description: builtins.str
    """Description of the application. 0-256 characters long."""
    status: global___Status.ValueType
    """Current status of the application."""
    @property
    def group_claims_settings(self) -> global___GroupClaimsSettings:
        """Settings of the group claims"""

    @property
    def client_grant(self) -> global___ClientGrant:
        """Represents current connection to the OAuth client with specified scopes"""

    @property
    def labels(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]:
        """Resource labels as `` key:value `` pairs."""

    @property
    def created_at(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """Creation timestamp."""

    @property
    def updated_at(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """Modification timestamp."""

    def __init__(
        self,
        *,
        id: builtins.str = ...,
        name: builtins.str = ...,
        organization_id: builtins.str = ...,
        description: builtins.str = ...,
        group_claims_settings: global___GroupClaimsSettings | None = ...,
        client_grant: global___ClientGrant | None = ...,
        status: global___Status.ValueType = ...,
        labels: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        created_at: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        updated_at: google.protobuf.timestamp_pb2.Timestamp | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["client_grant", b"client_grant", "created_at", b"created_at", "group_claims_settings", b"group_claims_settings", "updated_at", b"updated_at"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["client_grant", b"client_grant", "created_at", b"created_at", "description", b"description", "group_claims_settings", b"group_claims_settings", "id", b"id", "labels", b"labels", "name", b"name", "organization_id", b"organization_id", "status", b"status", "updated_at", b"updated_at"]) -> None: ...

global___Application = Application

@typing.final
class GroupClaimsSettings(google.protobuf.message.Message):
    """Settings of the group claims"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    GROUP_DISTRIBUTION_TYPE_FIELD_NUMBER: builtins.int
    group_distribution_type: global___GroupDistributionType.ValueType
    """Represents current distribution type of the groups. I.e. which groups are visible for the application users."""
    def __init__(
        self,
        *,
        group_distribution_type: global___GroupDistributionType.ValueType = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["group_distribution_type", b"group_distribution_type"]) -> None: ...

global___GroupClaimsSettings = GroupClaimsSettings

@typing.final
class ClientGrant(google.protobuf.message.Message):
    """Represents connection to the OAuth client with specified scopes"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CLIENT_ID_FIELD_NUMBER: builtins.int
    AUTHORIZED_SCOPES_FIELD_NUMBER: builtins.int
    client_id: builtins.str
    """OAuth client id"""
    @property
    def authorized_scopes(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """List of authorized client scopes by the application"""

    def __init__(
        self,
        *,
        client_id: builtins.str = ...,
        authorized_scopes: collections.abc.Iterable[builtins.str] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["authorized_scopes", b"authorized_scopes", "client_id", b"client_id"]) -> None: ...

global___ClientGrant = ClientGrant



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: yandex/cloud/billing/usage_records/v1/consumption_core_service.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'yandex/cloud/billing/usage_records/v1/consumption_core_service.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from yandex.cloud.billing.usage_records.v1 import billing_types_pb2 as yandex_dot_cloud_dot_billing_dot_usage__records_dot_v1_dot_billing__types__pb2
from yandex.cloud.billing.usage_records.v1 import common_types_pb2 as yandex_dot_cloud_dot_billing_dot_usage__records_dot_v1_dot_common__types__pb2
from yandex.cloud.billing.usage_records.v1 import credit_pb2 as yandex_dot_cloud_dot_billing_dot_usage__records_dot_v1_dot_credit__pb2
from yandex.cloud.billing.usage_records.v1 import consumption_core_pb2 as yandex_dot_cloud_dot_billing_dot_usage__records_dot_v1_dot_consumption__core__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nDyandex/cloud/billing/usage_records/v1/consumption_core_service.proto\x12%yandex.cloud.billing.usage_records.v1\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x39yandex/cloud/billing/usage_records/v1/billing_types.proto\x1a\x38yandex/cloud/billing/usage_records/v1/common_types.proto\x1a\x32yandex/cloud/billing/usage_records/v1/credit.proto\x1a<yandex/cloud/billing/usage_records/v1/consumption_core.proto\x1a\x1dyandex/cloud/validation.proto\"\x8c\x04\n\x12UsageReportRequest\x12 \n\x12\x62illing_account_id\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\x12\x34\n\nstart_date\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x04\xe8\xc7\x31\x01\x12\x32\n\x08\x65nd_date\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x04\xe8\xc7\x31\x01\x12\x11\n\tcloud_ids\x18\x04 \x03(\t\x12\x12\n\nfolder_ids\x18\x05 \x03(\t\x12\x13\n\x0bservice_ids\x18\x06 \x03(\t\x12\x0f\n\x07sku_ids\x18\x07 \x03(\t\x12U\n\x06labels\x18\x08 \x03(\x0b\x32\x45.yandex.cloud.billing.usage_records.v1.UsageReportRequest.LabelsEntry\x12\x14\n\x0cresource_ids\x18\t \x03(\t\x12O\n\x12\x61ggregation_period\x18\n \x01(\x0e\x32\x33.yandex.cloud.billing.usage_records.v1.TimeGrouping\x1a_\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12?\n\x05value\x18\x02 \x01(\x0b\x32\x30.yandex.cloud.billing.usage_records.v1.LabelList:\x02\x38\x01\"\xa2\x03\n!BillingAccountUsageReportResponse\x12\x41\n\x08\x63urrency\x18\x01 \x01(\x0e\x32/.yandex.cloud.billing.usage_records.v1.Currency\x12\x42\n\x04\x63ost\x18\x02 \x01(\x0b\x32\x34.yandex.cloud.billing.usage_records.v1.StringDecimal\x12L\n\x0e\x63redit_details\x18\x03 \x01(\x0b\x32\x34.yandex.cloud.billing.usage_records.v1.CreditDetails\x12\x45\n\x07\x65xpense\x18\x04 \x01(\x0b\x32\x34.yandex.cloud.billing.usage_records.v1.StringDecimal\x12\x61\n\rentities_data\x18\x05 \x03(\x0b\x32J.yandex.cloud.billing.usage_records.v1.BillingAccountUsageReportEntityData\"\x90\x03\n\x18\x43loudUsageReportResponse\x12\x41\n\x08\x63urrency\x18\x01 \x01(\x0e\x32/.yandex.cloud.billing.usage_records.v1.Currency\x12\x42\n\x04\x63ost\x18\x02 \x01(\x0b\x32\x34.yandex.cloud.billing.usage_records.v1.StringDecimal\x12L\n\x0e\x63redit_details\x18\x03 \x01(\x0b\x32\x34.yandex.cloud.billing.usage_records.v1.CreditDetails\x12\x45\n\x07\x65xpense\x18\x04 \x01(\x0b\x32\x34.yandex.cloud.billing.usage_records.v1.StringDecimal\x12X\n\rentities_data\x18\x05 \x03(\x0b\x32\x41.yandex.cloud.billing.usage_records.v1.CloudUsageReportEntityData\"\x92\x03\n\x19\x46olderUsageReportResponse\x12\x41\n\x08\x63urrency\x18\x01 \x01(\x0e\x32/.yandex.cloud.billing.usage_records.v1.Currency\x12\x42\n\x04\x63ost\x18\x02 \x01(\x0b\x32\x34.yandex.cloud.billing.usage_records.v1.StringDecimal\x12L\n\x0e\x63redit_details\x18\x03 \x01(\x0b\x32\x34.yandex.cloud.billing.usage_records.v1.CreditDetails\x12\x45\n\x07\x65xpense\x18\x04 \x01(\x0b\x32\x34.yandex.cloud.billing.usage_records.v1.StringDecimal\x12Y\n\rentities_data\x18\x05 \x03(\x0b\x32\x42.yandex.cloud.billing.usage_records.v1.FolderUsageReportEntityData\"\x94\x03\n\x1aServiceUsageReportResponse\x12\x41\n\x08\x63urrency\x18\x01 \x01(\x0e\x32/.yandex.cloud.billing.usage_records.v1.Currency\x12\x42\n\x04\x63ost\x18\x02 \x01(\x0b\x32\x34.yandex.cloud.billing.usage_records.v1.StringDecimal\x12L\n\x0e\x63redit_details\x18\x03 \x01(\x0b\x32\x34.yandex.cloud.billing.usage_records.v1.CreditDetails\x12\x45\n\x07\x65xpense\x18\x04 \x01(\x0b\x32\x34.yandex.cloud.billing.usage_records.v1.StringDecimal\x12Z\n\rentities_data\x18\x05 \x03(\x0b\x32\x43.yandex.cloud.billing.usage_records.v1.ServiceUsageReportEntityData\"\x8c\x03\n\x16SKUUsageReportResponse\x12\x41\n\x08\x63urrency\x18\x01 \x01(\x0e\x32/.yandex.cloud.billing.usage_records.v1.Currency\x12\x42\n\x04\x63ost\x18\x02 \x01(\x0b\x32\x34.yandex.cloud.billing.usage_records.v1.StringDecimal\x12L\n\x0e\x63redit_details\x18\x03 \x01(\x0b\x32\x34.yandex.cloud.billing.usage_records.v1.CreditDetails\x12\x45\n\x07\x65xpense\x18\x04 \x01(\x0b\x32\x34.yandex.cloud.billing.usage_records.v1.StringDecimal\x12V\n\rentities_data\x18\x05 \x03(\x0b\x32?.yandex.cloud.billing.usage_records.v1.SKUUsageReportEntityData\"\x96\x03\n\x1bResourceUsageReportResponse\x12\x41\n\x08\x63urrency\x18\x01 \x01(\x0e\x32/.yandex.cloud.billing.usage_records.v1.Currency\x12\x42\n\x04\x63ost\x18\x02 \x01(\x0b\x32\x34.yandex.cloud.billing.usage_records.v1.StringDecimal\x12L\n\x0e\x63redit_details\x18\x03 \x01(\x0b\x32\x34.yandex.cloud.billing.usage_records.v1.CreditDetails\x12\x45\n\x07\x65xpense\x18\x04 \x01(\x0b\x32\x34.yandex.cloud.billing.usage_records.v1.StringDecimal\x12[\n\rentities_data\x18\x05 \x03(\x0b\x32\x44.yandex.cloud.billing.usage_records.v1.ResourceUsageReportEntityData\"\x93\x03\n\x1bLabelKeyUsageReportResponse\x12\x41\n\x08\x63urrency\x18\x01 \x01(\x0e\x32/.yandex.cloud.billing.usage_records.v1.Currency\x12\x42\n\x04\x63ost\x18\x02 \x01(\x0b\x32\x34.yandex.cloud.billing.usage_records.v1.StringDecimal\x12L\n\x0e\x63redit_details\x18\x03 \x01(\x0b\x32\x34.yandex.cloud.billing.usage_records.v1.CreditDetails\x12\x45\n\x07\x65xpense\x18\x04 \x01(\x0b\x32\x34.yandex.cloud.billing.usage_records.v1.StringDecimal\x12X\n\rentities_data\x18\x05 \x03(\x0b\x32\x41.yandex.cloud.billing.usage_records.v1.LabelUsageReportEntityData2\xc4\x08\n\x16\x43onsumptionCoreService\x12\xa3\x01\n\x1cGetBillingAccountUsageReport\x12\x39.yandex.cloud.billing.usage_records.v1.UsageReportRequest\x1aH.yandex.cloud.billing.usage_records.v1.BillingAccountUsageReportResponse\x12\x91\x01\n\x13GetCloudUsageReport\x12\x39.yandex.cloud.billing.usage_records.v1.UsageReportRequest\x1a?.yandex.cloud.billing.usage_records.v1.CloudUsageReportResponse\x12\x93\x01\n\x14GetFolderUsageReport\x12\x39.yandex.cloud.billing.usage_records.v1.UsageReportRequest\x1a@.yandex.cloud.billing.usage_records.v1.FolderUsageReportResponse\x12\x95\x01\n\x15GetServiceUsageReport\x12\x39.yandex.cloud.billing.usage_records.v1.UsageReportRequest\x1a\x41.yandex.cloud.billing.usage_records.v1.ServiceUsageReportResponse\x12\x8d\x01\n\x11GetSKUUsageReport\x12\x39.yandex.cloud.billing.usage_records.v1.UsageReportRequest\x1a=.yandex.cloud.billing.usage_records.v1.SKUUsageReportResponse\x12\x97\x01\n\x16GetResourceUsageReport\x12\x39.yandex.cloud.billing.usage_records.v1.UsageReportRequest\x1a\x42.yandex.cloud.billing.usage_records.v1.ResourceUsageReportResponse\x12\x97\x01\n\x16GetLabelKeyUsageReport\x12\x39.yandex.cloud.billing.usage_records.v1.UsageReportRequest\x1a\x42.yandex.cloud.billing.usage_records.v1.LabelKeyUsageReportResponseB\x83\x01\n)yandex.cloud.api.billing.usage_records.v1ZVgithub.com/yandex-cloud/go-genproto/yandex/cloud/billing/usage_records/v1;usageRecordsb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.billing.usage_records.v1.consumption_core_service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n)yandex.cloud.api.billing.usage_records.v1ZVgithub.com/yandex-cloud/go-genproto/yandex/cloud/billing/usage_records/v1;usageRecords'
  _globals['_USAGEREPORTREQUEST_LABELSENTRY']._loaded_options = None
  _globals['_USAGEREPORTREQUEST_LABELSENTRY']._serialized_options = b'8\001'
  _globals['_USAGEREPORTREQUEST'].fields_by_name['billing_account_id']._loaded_options = None
  _globals['_USAGEREPORTREQUEST'].fields_by_name['billing_account_id']._serialized_options = b'\350\3071\001'
  _globals['_USAGEREPORTREQUEST'].fields_by_name['start_date']._loaded_options = None
  _globals['_USAGEREPORTREQUEST'].fields_by_name['start_date']._serialized_options = b'\350\3071\001'
  _globals['_USAGEREPORTREQUEST'].fields_by_name['end_date']._loaded_options = None
  _globals['_USAGEREPORTREQUEST'].fields_by_name['end_date']._serialized_options = b'\350\3071\001'
  _globals['_USAGEREPORTREQUEST']._serialized_start=407
  _globals['_USAGEREPORTREQUEST']._serialized_end=931
  _globals['_USAGEREPORTREQUEST_LABELSENTRY']._serialized_start=836
  _globals['_USAGEREPORTREQUEST_LABELSENTRY']._serialized_end=931
  _globals['_BILLINGACCOUNTUSAGEREPORTRESPONSE']._serialized_start=934
  _globals['_BILLINGACCOUNTUSAGEREPORTRESPONSE']._serialized_end=1352
  _globals['_CLOUDUSAGEREPORTRESPONSE']._serialized_start=1355
  _globals['_CLOUDUSAGEREPORTRESPONSE']._serialized_end=1755
  _globals['_FOLDERUSAGEREPORTRESPONSE']._serialized_start=1758
  _globals['_FOLDERUSAGEREPORTRESPONSE']._serialized_end=2160
  _globals['_SERVICEUSAGEREPORTRESPONSE']._serialized_start=2163
  _globals['_SERVICEUSAGEREPORTRESPONSE']._serialized_end=2567
  _globals['_SKUUSAGEREPORTRESPONSE']._serialized_start=2570
  _globals['_SKUUSAGEREPORTRESPONSE']._serialized_end=2966
  _globals['_RESOURCEUSAGEREPORTRESPONSE']._serialized_start=2969
  _globals['_RESOURCEUSAGEREPORTRESPONSE']._serialized_end=3375
  _globals['_LABELKEYUSAGEREPORTRESPONSE']._serialized_start=3378
  _globals['_LABELKEYUSAGEREPORTRESPONSE']._serialized_end=3781
  _globals['_CONSUMPTIONCORESERVICE']._serialized_start=3784
  _globals['_CONSUMPTIONCORESERVICE']._serialized_end=4876
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.duration_pb2
import google.protobuf.field_mask_pb2
import google.protobuf.internal.containers
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import google.protobuf.timestamp_pb2
import sys
import typing
import yandex.cloud.organizationmanager.v1.mfa_enforcement_pb2

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class CreateMfaEnforcementRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class _Status:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _StatusEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[CreateMfaEnforcementRequest._Status.ValueType], builtins.type):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        STATUS_UNSPECIFIED: CreateMfaEnforcementRequest._Status.ValueType  # 0
        """status upspecified"""
        STATUS_ACTIVE: CreateMfaEnforcementRequest._Status.ValueType  # 1
        """active"""
        STATUS_INACTIVE: CreateMfaEnforcementRequest._Status.ValueType  # 2
        """inactive"""

    class Status(_Status, metaclass=_StatusEnumTypeWrapper): ...
    STATUS_UNSPECIFIED: CreateMfaEnforcementRequest.Status.ValueType  # 0
    """status upspecified"""
    STATUS_ACTIVE: CreateMfaEnforcementRequest.Status.ValueType  # 1
    """active"""
    STATUS_INACTIVE: CreateMfaEnforcementRequest.Status.ValueType  # 2
    """inactive"""

    ORGANIZATION_ID_FIELD_NUMBER: builtins.int
    ACR_ID_FIELD_NUMBER: builtins.int
    TTL_FIELD_NUMBER: builtins.int
    STATUS_FIELD_NUMBER: builtins.int
    APPLY_AT_FIELD_NUMBER: builtins.int
    ENROLL_WINDOW_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    organization_id: builtins.str
    """organization id of the MFA enforcement"""
    acr_id: builtins.str
    """acr id for the MFA enforcement. one of 'any-mfa' or 'phr',
    specification https://yandex.cloud/en/docs/organization/concepts/mfa?utm_referrer=https%3A%2F%2Fa.yandex-team.ru%2F#mfa-factors
    """
    status: global___CreateMfaEnforcementRequest.Status.ValueType
    """the MFA enforcement status"""
    name: builtins.str
    """the MFA enforcement name"""
    description: builtins.str
    """the MFA enforcement description"""
    @property
    def ttl(self) -> google.protobuf.duration_pb2.Duration:
        """the period during which the entered MFA factor will be considered valid and the
        corresponding acr will be regarded as satisfied
        max 1 year
        """

    @property
    def apply_at(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """the MFA enforcement application start time"""

    @property
    def enroll_window(self) -> google.protobuf.duration_pb2.Duration:
        """the MFA enforcement enroll window"""

    def __init__(
        self,
        *,
        organization_id: builtins.str = ...,
        acr_id: builtins.str = ...,
        ttl: google.protobuf.duration_pb2.Duration | None = ...,
        status: global___CreateMfaEnforcementRequest.Status.ValueType = ...,
        apply_at: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        enroll_window: google.protobuf.duration_pb2.Duration | None = ...,
        name: builtins.str = ...,
        description: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["apply_at", b"apply_at", "enroll_window", b"enroll_window", "ttl", b"ttl"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["acr_id", b"acr_id", "apply_at", b"apply_at", "description", b"description", "enroll_window", b"enroll_window", "name", b"name", "organization_id", b"organization_id", "status", b"status", "ttl", b"ttl"]) -> None: ...

global___CreateMfaEnforcementRequest = CreateMfaEnforcementRequest

@typing.final
class CreateMfaEnforcementMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ORGANIZATION_ID_FIELD_NUMBER: builtins.int
    MFA_ENFORCEMENT_ID_FIELD_NUMBER: builtins.int
    organization_id: builtins.str
    """organization id of the MFA enforcement"""
    mfa_enforcement_id: builtins.str
    """id of the MFA enforcement"""
    def __init__(
        self,
        *,
        organization_id: builtins.str = ...,
        mfa_enforcement_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["mfa_enforcement_id", b"mfa_enforcement_id", "organization_id", b"organization_id"]) -> None: ...

global___CreateMfaEnforcementMetadata = CreateMfaEnforcementMetadata

@typing.final
class UpdateMfaEnforcementRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class _Status:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _StatusEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[UpdateMfaEnforcementRequest._Status.ValueType], builtins.type):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        STATUS_UNSPECIFIED: UpdateMfaEnforcementRequest._Status.ValueType  # 0
        """status upspecified"""
        STATUS_ACTIVE: UpdateMfaEnforcementRequest._Status.ValueType  # 1
        """active"""
        STATUS_INACTIVE: UpdateMfaEnforcementRequest._Status.ValueType  # 2
        """inactive"""

    class Status(_Status, metaclass=_StatusEnumTypeWrapper): ...
    STATUS_UNSPECIFIED: UpdateMfaEnforcementRequest.Status.ValueType  # 0
    """status upspecified"""
    STATUS_ACTIVE: UpdateMfaEnforcementRequest.Status.ValueType  # 1
    """active"""
    STATUS_INACTIVE: UpdateMfaEnforcementRequest.Status.ValueType  # 2
    """inactive"""

    MFA_ENFORCEMENT_ID_FIELD_NUMBER: builtins.int
    ACR_ID_FIELD_NUMBER: builtins.int
    TTL_FIELD_NUMBER: builtins.int
    STATUS_FIELD_NUMBER: builtins.int
    APPLY_AT_FIELD_NUMBER: builtins.int
    ENROLL_WINDOW_FIELD_NUMBER: builtins.int
    UPDATE_MASK_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    mfa_enforcement_id: builtins.str
    """id of the MFA enforcement"""
    acr_id: builtins.str
    """acr id for the MFA enforcement. one of 'any-mfa' or 'phr',
    specification https://yandex.cloud/en/docs/organization/concepts/mfa?utm_referrer=https%3A%2F%2Fa.yandex-team.ru%2F#mfa-factors
    """
    status: global___UpdateMfaEnforcementRequest.Status.ValueType
    """the MFA enforcement status"""
    name: builtins.str
    """the MFA enforcement name"""
    description: builtins.str
    """the MFA enforcement description"""
    @property
    def ttl(self) -> google.protobuf.duration_pb2.Duration:
        """the period during which the entered MFA factor will be considered valid and the
        corresponding acr will be regarded as satisfied
        max 1 year
        """

    @property
    def apply_at(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """the MFA enforcement application start time"""

    @property
    def enroll_window(self) -> google.protobuf.duration_pb2.Duration:
        """the MFA enforcement enroll window"""

    @property
    def update_mask(self) -> google.protobuf.field_mask_pb2.FieldMask:
        """field mask to specify which fields of the MFA enforcement resource should be updated"""

    def __init__(
        self,
        *,
        mfa_enforcement_id: builtins.str = ...,
        acr_id: builtins.str = ...,
        ttl: google.protobuf.duration_pb2.Duration | None = ...,
        status: global___UpdateMfaEnforcementRequest.Status.ValueType = ...,
        apply_at: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        enroll_window: google.protobuf.duration_pb2.Duration | None = ...,
        update_mask: google.protobuf.field_mask_pb2.FieldMask | None = ...,
        name: builtins.str = ...,
        description: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["apply_at", b"apply_at", "enroll_window", b"enroll_window", "ttl", b"ttl", "update_mask", b"update_mask"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["acr_id", b"acr_id", "apply_at", b"apply_at", "description", b"description", "enroll_window", b"enroll_window", "mfa_enforcement_id", b"mfa_enforcement_id", "name", b"name", "status", b"status", "ttl", b"ttl", "update_mask", b"update_mask"]) -> None: ...

global___UpdateMfaEnforcementRequest = UpdateMfaEnforcementRequest

@typing.final
class UpdateMfaEnforcementMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MFA_ENFORCEMENT_ID_FIELD_NUMBER: builtins.int
    mfa_enforcement_id: builtins.str
    """id of the MFA enforcement"""
    def __init__(
        self,
        *,
        mfa_enforcement_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["mfa_enforcement_id", b"mfa_enforcement_id"]) -> None: ...

global___UpdateMfaEnforcementMetadata = UpdateMfaEnforcementMetadata

@typing.final
class ActivateMfaEnforcementRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MFA_ENFORCEMENT_ID_FIELD_NUMBER: builtins.int
    mfa_enforcement_id: builtins.str
    """id of the MFA enforcement"""
    def __init__(
        self,
        *,
        mfa_enforcement_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["mfa_enforcement_id", b"mfa_enforcement_id"]) -> None: ...

global___ActivateMfaEnforcementRequest = ActivateMfaEnforcementRequest

@typing.final
class ActivateMfaEnforcementMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MFA_ENFORCEMENT_ID_FIELD_NUMBER: builtins.int
    mfa_enforcement_id: builtins.str
    """id of the MFA enforcement"""
    def __init__(
        self,
        *,
        mfa_enforcement_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["mfa_enforcement_id", b"mfa_enforcement_id"]) -> None: ...

global___ActivateMfaEnforcementMetadata = ActivateMfaEnforcementMetadata

@typing.final
class DeactivateMfaEnforcementRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MFA_ENFORCEMENT_ID_FIELD_NUMBER: builtins.int
    mfa_enforcement_id: builtins.str
    """id of the MFA enforcement"""
    def __init__(
        self,
        *,
        mfa_enforcement_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["mfa_enforcement_id", b"mfa_enforcement_id"]) -> None: ...

global___DeactivateMfaEnforcementRequest = DeactivateMfaEnforcementRequest

@typing.final
class DeactivateMfaEnforcementMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MFA_ENFORCEMENT_ID_FIELD_NUMBER: builtins.int
    mfa_enforcement_id: builtins.str
    """id of the MFA enforcement"""
    def __init__(
        self,
        *,
        mfa_enforcement_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["mfa_enforcement_id", b"mfa_enforcement_id"]) -> None: ...

global___DeactivateMfaEnforcementMetadata = DeactivateMfaEnforcementMetadata

@typing.final
class DeleteMfaEnforcementRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MFA_ENFORCEMENT_ID_FIELD_NUMBER: builtins.int
    mfa_enforcement_id: builtins.str
    """id of the MFA enforcement"""
    def __init__(
        self,
        *,
        mfa_enforcement_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["mfa_enforcement_id", b"mfa_enforcement_id"]) -> None: ...

global___DeleteMfaEnforcementRequest = DeleteMfaEnforcementRequest

@typing.final
class DeleteMfaEnforcementMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MFA_ENFORCEMENT_ID_FIELD_NUMBER: builtins.int
    mfa_enforcement_id: builtins.str
    """id of the MFA enforcement"""
    def __init__(
        self,
        *,
        mfa_enforcement_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["mfa_enforcement_id", b"mfa_enforcement_id"]) -> None: ...

global___DeleteMfaEnforcementMetadata = DeleteMfaEnforcementMetadata

@typing.final
class GetMfaEnforcementRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MFA_ENFORCEMENT_ID_FIELD_NUMBER: builtins.int
    mfa_enforcement_id: builtins.str
    """id of the MFA enforcement"""
    def __init__(
        self,
        *,
        mfa_enforcement_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["mfa_enforcement_id", b"mfa_enforcement_id"]) -> None: ...

global___GetMfaEnforcementRequest = GetMfaEnforcementRequest

@typing.final
class ListMfaEnforcementsRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ORGANIZATION_ID_FIELD_NUMBER: builtins.int
    PAGE_SIZE_FIELD_NUMBER: builtins.int
    PAGE_TOKEN_FIELD_NUMBER: builtins.int
    organization_id: builtins.str
    """organization id"""
    page_size: builtins.int
    """the maximum number of results per page to return"""
    page_token: builtins.str
    """page token"""
    def __init__(
        self,
        *,
        organization_id: builtins.str = ...,
        page_size: builtins.int = ...,
        page_token: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["organization_id", b"organization_id", "page_size", b"page_size", "page_token", b"page_token"]) -> None: ...

global___ListMfaEnforcementsRequest = ListMfaEnforcementsRequest

@typing.final
class ListMfaEnforcementsResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MFA_ENFORCEMENTS_FIELD_NUMBER: builtins.int
    NEXT_PAGE_TOKEN_FIELD_NUMBER: builtins.int
    next_page_token: builtins.str
    """token to get the next page of results"""
    @property
    def mfa_enforcements(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[yandex.cloud.organizationmanager.v1.mfa_enforcement_pb2.MfaEnforcement]:
        """list of MFA enforcements for the specified organization"""

    def __init__(
        self,
        *,
        mfa_enforcements: collections.abc.Iterable[yandex.cloud.organizationmanager.v1.mfa_enforcement_pb2.MfaEnforcement] | None = ...,
        next_page_token: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["mfa_enforcements", b"mfa_enforcements", "next_page_token", b"next_page_token"]) -> None: ...

global___ListMfaEnforcementsResponse = ListMfaEnforcementsResponse

@typing.final
class UpdateAudienceRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MFA_ENFORCEMENT_ID_FIELD_NUMBER: builtins.int
    AUDIENCE_DELTAS_FIELD_NUMBER: builtins.int
    mfa_enforcement_id: builtins.str
    """id of the MFA enforcement"""
    @property
    def audience_deltas(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___AudienceDelta]:
        """MFA enforcement's audience to update"""

    def __init__(
        self,
        *,
        mfa_enforcement_id: builtins.str = ...,
        audience_deltas: collections.abc.Iterable[global___AudienceDelta] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["audience_deltas", b"audience_deltas", "mfa_enforcement_id", b"mfa_enforcement_id"]) -> None: ...

global___UpdateAudienceRequest = UpdateAudienceRequest

@typing.final
class UpdateAudienceResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MFA_ENFORCEMENT_ID_FIELD_NUMBER: builtins.int
    EFFECTIVE_DELTAS_FIELD_NUMBER: builtins.int
    mfa_enforcement_id: builtins.str
    """id of the MFA enforcement"""
    @property
    def effective_deltas(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___AudienceDelta]:
        """updated MFA enforcement's audience"""

    def __init__(
        self,
        *,
        mfa_enforcement_id: builtins.str = ...,
        effective_deltas: collections.abc.Iterable[global___AudienceDelta] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["effective_deltas", b"effective_deltas", "mfa_enforcement_id", b"mfa_enforcement_id"]) -> None: ...

global___UpdateAudienceResponse = UpdateAudienceResponse

@typing.final
class AudienceDelta(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class _Action:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _ActionEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[AudienceDelta._Action.ValueType], builtins.type):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        ACTION_UNSPECIFIED: AudienceDelta._Action.ValueType  # 0
        """action unspecified"""
        ACTION_ADD: AudienceDelta._Action.ValueType  # 1
        """add subject to audience"""
        ACTION_REMOVE: AudienceDelta._Action.ValueType  # 2
        """remove subject from audience"""

    class Action(_Action, metaclass=_ActionEnumTypeWrapper): ...
    ACTION_UNSPECIFIED: AudienceDelta.Action.ValueType  # 0
    """action unspecified"""
    ACTION_ADD: AudienceDelta.Action.ValueType  # 1
    """add subject to audience"""
    ACTION_REMOVE: AudienceDelta.Action.ValueType  # 2
    """remove subject from audience"""

    ACTION_FIELD_NUMBER: builtins.int
    SUBJECT_ID_FIELD_NUMBER: builtins.int
    action: global___AudienceDelta.Action.ValueType
    """action to perform"""
    subject_id: builtins.str
    """subject id"""
    def __init__(
        self,
        *,
        action: global___AudienceDelta.Action.ValueType = ...,
        subject_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["action", b"action", "subject_id", b"subject_id"]) -> None: ...

global___AudienceDelta = AudienceDelta

@typing.final
class UpdateAudienceMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MFA_ENFORCEMENT_ID_FIELD_NUMBER: builtins.int
    mfa_enforcement_id: builtins.str
    """id of the MFA enforcement"""
    def __init__(
        self,
        *,
        mfa_enforcement_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["mfa_enforcement_id", b"mfa_enforcement_id"]) -> None: ...

global___UpdateAudienceMetadata = UpdateAudienceMetadata

@typing.final
class ListAudienceRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MFA_ENFORCEMENT_ID_FIELD_NUMBER: builtins.int
    PAGE_SIZE_FIELD_NUMBER: builtins.int
    PAGE_TOKEN_FIELD_NUMBER: builtins.int
    mfa_enforcement_id: builtins.str
    """id of the MFA enforcement"""
    page_size: builtins.int
    """the maximum number of results per page to return"""
    page_token: builtins.str
    """page token"""
    def __init__(
        self,
        *,
        mfa_enforcement_id: builtins.str = ...,
        page_size: builtins.int = ...,
        page_token: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["mfa_enforcement_id", b"mfa_enforcement_id", "page_size", b"page_size", "page_token", b"page_token"]) -> None: ...

global___ListAudienceRequest = ListAudienceRequest

@typing.final
class ListAudienceResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing.final
    class Subject(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        ID_FIELD_NUMBER: builtins.int
        TYPE_FIELD_NUMBER: builtins.int
        id: builtins.str
        """subject id"""
        type: builtins.str
        """subject type"""
        def __init__(
            self,
            *,
            id: builtins.str = ...,
            type: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["id", b"id", "type", b"type"]) -> None: ...

    SUBJECTS_FIELD_NUMBER: builtins.int
    NEXT_PAGE_TOKEN_FIELD_NUMBER: builtins.int
    next_page_token: builtins.str
    """token to get the next page of results"""
    @property
    def subjects(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ListAudienceResponse.Subject]:
        """MFA enforcement's audience"""

    def __init__(
        self,
        *,
        subjects: collections.abc.Iterable[global___ListAudienceResponse.Subject] | None = ...,
        next_page_token: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["next_page_token", b"next_page_token", "subjects", b"subjects"]) -> None: ...

global___ListAudienceResponse = ListAudienceResponse

@typing.final
class UpdateExcludedAudienceRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MFA_ENFORCEMENT_ID_FIELD_NUMBER: builtins.int
    AUDIENCE_DELTAS_FIELD_NUMBER: builtins.int
    mfa_enforcement_id: builtins.str
    """id of the MFA enforcement"""
    @property
    def audience_deltas(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___AudienceDelta]:
        """updated MFA enforcement's excluded audience"""

    def __init__(
        self,
        *,
        mfa_enforcement_id: builtins.str = ...,
        audience_deltas: collections.abc.Iterable[global___AudienceDelta] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["audience_deltas", b"audience_deltas", "mfa_enforcement_id", b"mfa_enforcement_id"]) -> None: ...

global___UpdateExcludedAudienceRequest = UpdateExcludedAudienceRequest

@typing.final
class UpdateExcludedAudienceResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MFA_ENFORCEMENT_ID_FIELD_NUMBER: builtins.int
    EFFECTIVE_DELTAS_FIELD_NUMBER: builtins.int
    mfa_enforcement_id: builtins.str
    """id of the MFA enforcement"""
    @property
    def effective_deltas(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___AudienceDelta]:
        """updated MFA enforcement's excluded audience"""

    def __init__(
        self,
        *,
        mfa_enforcement_id: builtins.str = ...,
        effective_deltas: collections.abc.Iterable[global___AudienceDelta] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["effective_deltas", b"effective_deltas", "mfa_enforcement_id", b"mfa_enforcement_id"]) -> None: ...

global___UpdateExcludedAudienceResponse = UpdateExcludedAudienceResponse

@typing.final
class UpdateExcludedAudienceMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MFA_ENFORCEMENT_ID_FIELD_NUMBER: builtins.int
    mfa_enforcement_id: builtins.str
    """id of the MFA enforcement"""
    def __init__(
        self,
        *,
        mfa_enforcement_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["mfa_enforcement_id", b"mfa_enforcement_id"]) -> None: ...

global___UpdateExcludedAudienceMetadata = UpdateExcludedAudienceMetadata

@typing.final
class ListExcludedAudienceRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MFA_ENFORCEMENT_ID_FIELD_NUMBER: builtins.int
    PAGE_SIZE_FIELD_NUMBER: builtins.int
    PAGE_TOKEN_FIELD_NUMBER: builtins.int
    mfa_enforcement_id: builtins.str
    """id of the MFA enforcement"""
    page_size: builtins.int
    """the maximum number of results per page to return"""
    page_token: builtins.str
    """page token"""
    def __init__(
        self,
        *,
        mfa_enforcement_id: builtins.str = ...,
        page_size: builtins.int = ...,
        page_token: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["mfa_enforcement_id", b"mfa_enforcement_id", "page_size", b"page_size", "page_token", b"page_token"]) -> None: ...

global___ListExcludedAudienceRequest = ListExcludedAudienceRequest

@typing.final
class ListExcludedAudienceResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing.final
    class Subject(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        ID_FIELD_NUMBER: builtins.int
        TYPE_FIELD_NUMBER: builtins.int
        id: builtins.str
        """subject id"""
        type: builtins.str
        """subject type"""
        def __init__(
            self,
            *,
            id: builtins.str = ...,
            type: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["id", b"id", "type", b"type"]) -> None: ...

    SUBJECTS_FIELD_NUMBER: builtins.int
    NEXT_PAGE_TOKEN_FIELD_NUMBER: builtins.int
    next_page_token: builtins.str
    """token to get the next page of results"""
    @property
    def subjects(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ListExcludedAudienceResponse.Subject]:
        """MFA enforcement's audience"""

    def __init__(
        self,
        *,
        subjects: collections.abc.Iterable[global___ListExcludedAudienceResponse.Subject] | None = ...,
        next_page_token: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["next_page_token", b"next_page_token", "subjects", b"subjects"]) -> None: ...

global___ListExcludedAudienceResponse = ListExcludedAudienceResponse



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc
import warnings

from yandex.cloud.billing.usage_records.v1 import metadata_service_pb2 as yandex_dot_cloud_dot_billing_dot_usage__records_dot_v1_dot_metadata__service__pb2

GRPC_GENERATED_VERSION = '1.70.0'
GRPC_VERSION = grpc.__version__
_version_not_supported = False

try:
    from grpc._utilities import first_version_is_lower
    _version_not_supported = first_version_is_lower(GRPC_VERSION, GRPC_GENERATED_VERSION)
except ImportError:
    _version_not_supported = True

if _version_not_supported:
    raise RuntimeError(
        f'The grpc package installed is at version {GRPC_VERSION},'
        + f' but the generated code in yandex/cloud/billing/usage_records/v1/metadata_service_pb2_grpc.py depends on'
        + f' grpcio>={GRPC_GENERATED_VERSION}.'
        + f' Please upgrade your grpc module to grpcio>={GRPC_GENERATED_VERSION}'
        + f' or downgrade your generated code using grpcio-tools<={GRPC_VERSION}.'
    )


class MetadataServiceStub(object):
    """MetadataService service for retrieving metadata related to usage records

    The MetadataService provides a set of methods for retrieving metadata and reference information
    about billing usage records within a specific billing account and date range. This metadata
    includes information about clouds, services, SKUs, labels, and resources
    to understand the available entity structure before building detailed usage reports.

    Required permissions:
    All methods in this service require one of the following permissions on the specified billing account:
    - `billing.accounts.getReport`

    Rate limits:
    This API is limited to 1 request per minute per IP address.
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.GetUsage = channel.unary_unary(
                '/yandex.cloud.billing.usage_records.v1.MetadataService/GetUsage',
                request_serializer=yandex_dot_cloud_dot_billing_dot_usage__records_dot_v1_dot_metadata__service__pb2.GetUsageRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_billing_dot_usage__records_dot_v1_dot_metadata__service__pb2.GetUsageResponse.FromString,
                _registered_method=True)
        self.GetLabel = channel.unary_unary(
                '/yandex.cloud.billing.usage_records.v1.MetadataService/GetLabel',
                request_serializer=yandex_dot_cloud_dot_billing_dot_usage__records_dot_v1_dot_metadata__service__pb2.GetLabelRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_billing_dot_usage__records_dot_v1_dot_metadata__service__pb2.GetLabelResponse.FromString,
                _registered_method=True)
        self.GetCloud = channel.unary_unary(
                '/yandex.cloud.billing.usage_records.v1.MetadataService/GetCloud',
                request_serializer=yandex_dot_cloud_dot_billing_dot_usage__records_dot_v1_dot_metadata__service__pb2.GetCloudRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_billing_dot_usage__records_dot_v1_dot_metadata__service__pb2.GetCloudResponse.FromString,
                _registered_method=True)
        self.GetResourceIDs = channel.unary_unary(
                '/yandex.cloud.billing.usage_records.v1.MetadataService/GetResourceIDs',
                request_serializer=yandex_dot_cloud_dot_billing_dot_usage__records_dot_v1_dot_metadata__service__pb2.GetResourceIDsRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_billing_dot_usage__records_dot_v1_dot_metadata__service__pb2.GetResourceIDsResponse.FromString,
                _registered_method=True)


class MetadataServiceServicer(object):
    """MetadataService service for retrieving metadata related to usage records

    The MetadataService provides a set of methods for retrieving metadata and reference information
    about billing usage records within a specific billing account and date range. This metadata
    includes information about clouds, services, SKUs, labels, and resources
    to understand the available entity structure before building detailed usage reports.

    Required permissions:
    All methods in this service require one of the following permissions on the specified billing account:
    - `billing.accounts.getReport`

    Rate limits:
    This API is limited to 1 request per minute per IP address.
    """

    def GetUsage(self, request, context):
        """GetUsage returns usage metadata including available clouds, services, SKUs, label keys, and date ranges
        for a specific billing account and date range.

        This method provides a view of all available entities
        that can be used for usage reporting within the specified date range
        for the billing account and all its sub-accounts including:
        - List of available clouds in provided data range
        - Available label keys that can be used for filtering or grouping
        - Available services
        - Available SKUs
        - Available billing accounts (user billing account and his sub-accounts)

        Implementation details:
        - Empty cloud_id values are translated to a "Usage is out of scope of the Cloud" designation
        - All data is filtered to only include items that had usage during the specified date range

        Error handling:
        - Returns INVALID_ARGUMENT if the request parameters fail validation
        - Returns UNAUTHENTICATED if the user is not authenticated or the billing account does not exist
        - Returns PERMISSION_DENIED if the user lacks required permissions
        - Returns INTERNAL for internal server errors

        Required permissions:
        - `billing.accounts.getReport` on the specified billing account
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetLabel(self, request, context):
        """GetLabel returns available label keys and values for a specific billing account
        with pagination support.

        This method retrieves all available label values for a specified label key
        within the given date range. It supports filtering by label value substring
        and provides pagination for handling large result sets.

        The method can be used in several ways:
        - With label_key only: Returns all values for that key with pagination
        - With label_key and label_value: Returns array of matching labelValues with pagination
        - With label_key and label_value_filter: Returns all values for that key with pagination
        and a separate array of labelValues from the labelValueFilters parameter
        - With label_key, label_value and label_value_filter: returns only an array of matching labelValues
        with pagination and ignores labelValueFilters (i.e., labelValueFilters won't be returned)

        Implementation details:
        - Case-insensitive label value matching when label_value is provided
        - When label_value is specified, label_value_filter is ignored
        - Label values are sorted alphabetically
        - Pagination occurs when results exceed page_size

        Error handling:
        - Returns INVALID_ARGUMENT if the request parameters fail validation
        - Returns UNAUTHENTICATED if the user is not authenticated or the billing account does not exist
        - Returns PERMISSION_DENIED if the user lacks required permissions
        - Returns INTERNAL for internal server errors

        Required permissions:
        - `billing.accounts.getReport` on the specified billing account
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetCloud(self, request, context):
        """GetCloud returns available folders for specified clouds within a billing account
        with optional filtering by cloud IDs, folder IDs and pagination support.

        This method returns a hierarchical view of clouds and their folders that the user
        has access to within the specified date range. Results can be filtered by
        specific cloud IDs and/or folder IDs, and pagination is supported for handling
        large result sets.

        Implementation details:
        - The method result does not contain empty cloud id information
        - Filtering is done using case-insensitive substring matching
        - Only clouds with at least one folder are included in the response
        - Folder pagination is based on folder IDs, ordered alphabetically
        - NextPageToken is only returned when there are more results available
        - Base64-encoded page tokens are used for pagination state

        Error handling:
        - Returns INVALID_ARGUMENT if the request parameters fail validation
        - Returns UNAUTHENTICATED if the user is not authenticated or the billing account does not exist
        - Returns PERMISSION_DENIED if the user lacks required permissions
        - Returns INTERNAL for internal server errors

        Required permissions:
        - `billing.accounts.getReport` on the specified billing account
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetResourceIDs(self, request, context):
        """GetResourceIDs returns all resource IDs for a specific billing account and date range
        with pagination support.

        This method retrieves a list of all resource IDs that have usage records
        within the specified date range and billing account. The results can be
        filtered by a case-insensitive substring search on the resource ID.

        Implementation details:
        - Filtering is done using case-insensitive substring matching
        - Only resource IDs with actual usage in the period are returned

        Error handling:
        - Returns INVALID_ARGUMENT if the request parameters fail validation
        - Returns UNAUTHENTICATED if the user is not authenticated or the billing account does not exist
        - Returns PERMISSION_DENIED if the user lacks required permissions
        - Returns INTERNAL for internal server errors

        Required permissions:
        - `billing.accounts.getReport` on the specified billing account

        Note: This RPC method is not yet implemented and will return UNIMPLEMENTED.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_MetadataServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'GetUsage': grpc.unary_unary_rpc_method_handler(
                    servicer.GetUsage,
                    request_deserializer=yandex_dot_cloud_dot_billing_dot_usage__records_dot_v1_dot_metadata__service__pb2.GetUsageRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_billing_dot_usage__records_dot_v1_dot_metadata__service__pb2.GetUsageResponse.SerializeToString,
            ),
            'GetLabel': grpc.unary_unary_rpc_method_handler(
                    servicer.GetLabel,
                    request_deserializer=yandex_dot_cloud_dot_billing_dot_usage__records_dot_v1_dot_metadata__service__pb2.GetLabelRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_billing_dot_usage__records_dot_v1_dot_metadata__service__pb2.GetLabelResponse.SerializeToString,
            ),
            'GetCloud': grpc.unary_unary_rpc_method_handler(
                    servicer.GetCloud,
                    request_deserializer=yandex_dot_cloud_dot_billing_dot_usage__records_dot_v1_dot_metadata__service__pb2.GetCloudRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_billing_dot_usage__records_dot_v1_dot_metadata__service__pb2.GetCloudResponse.SerializeToString,
            ),
            'GetResourceIDs': grpc.unary_unary_rpc_method_handler(
                    servicer.GetResourceIDs,
                    request_deserializer=yandex_dot_cloud_dot_billing_dot_usage__records_dot_v1_dot_metadata__service__pb2.GetResourceIDsRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_billing_dot_usage__records_dot_v1_dot_metadata__service__pb2.GetResourceIDsResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'yandex.cloud.billing.usage_records.v1.MetadataService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))
    server.add_registered_method_handlers('yandex.cloud.billing.usage_records.v1.MetadataService', rpc_method_handlers)


 # This class is part of an EXPERIMENTAL API.
class MetadataService(object):
    """MetadataService service for retrieving metadata related to usage records

    The MetadataService provides a set of methods for retrieving metadata and reference information
    about billing usage records within a specific billing account and date range. This metadata
    includes information about clouds, services, SKUs, labels, and resources
    to understand the available entity structure before building detailed usage reports.

    Required permissions:
    All methods in this service require one of the following permissions on the specified billing account:
    - `billing.accounts.getReport`

    Rate limits:
    This API is limited to 1 request per minute per IP address.
    """

    @staticmethod
    def GetUsage(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/yandex.cloud.billing.usage_records.v1.MetadataService/GetUsage',
            yandex_dot_cloud_dot_billing_dot_usage__records_dot_v1_dot_metadata__service__pb2.GetUsageRequest.SerializeToString,
            yandex_dot_cloud_dot_billing_dot_usage__records_dot_v1_dot_metadata__service__pb2.GetUsageResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def GetLabel(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/yandex.cloud.billing.usage_records.v1.MetadataService/GetLabel',
            yandex_dot_cloud_dot_billing_dot_usage__records_dot_v1_dot_metadata__service__pb2.GetLabelRequest.SerializeToString,
            yandex_dot_cloud_dot_billing_dot_usage__records_dot_v1_dot_metadata__service__pb2.GetLabelResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def GetCloud(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/yandex.cloud.billing.usage_records.v1.MetadataService/GetCloud',
            yandex_dot_cloud_dot_billing_dot_usage__records_dot_v1_dot_metadata__service__pb2.GetCloudRequest.SerializeToString,
            yandex_dot_cloud_dot_billing_dot_usage__records_dot_v1_dot_metadata__service__pb2.GetCloudResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def GetResourceIDs(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/yandex.cloud.billing.usage_records.v1.MetadataService/GetResourceIDs',
            yandex_dot_cloud_dot_billing_dot_usage__records_dot_v1_dot_metadata__service__pb2.GetResourceIDsRequest.SerializeToString,
            yandex_dot_cloud_dot_billing_dot_usage__records_dot_v1_dot_metadata__service__pb2.GetResourceIDsResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: yandex/cloud/baremetal/v1alpha/public_prefix_pool_service.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'yandex/cloud/baremetal/v1alpha/public_prefix_pool_service.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import field_mask_pb2 as google_dot_protobuf_dot_field__mask__pb2
from yandex.cloud.api import operation_pb2 as yandex_dot_cloud_dot_api_dot_operation__pb2
from yandex.cloud.baremetal.v1alpha import public_prefix_pool_pb2 as yandex_dot_cloud_dot_baremetal_dot_v1alpha_dot_public__prefix__pool__pb2
from yandex.cloud.operation import operation_pb2 as yandex_dot_cloud_dot_operation_dot_operation__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n?yandex/cloud/baremetal/v1alpha/public_prefix_pool_service.proto\x12\x1eyandex.cloud.baremetal.v1alpha\x1a google/protobuf/field_mask.proto\x1a yandex/cloud/api/operation.proto\x1a\x37yandex/cloud/baremetal/v1alpha/public_prefix_pool.proto\x1a&yandex/cloud/operation/operation.proto\x1a\x1dyandex/cloud/validation.proto\"Y\n\x1aGetPublicPrefixPoolRequest\x12;\n\x15public_prefix_pool_id\x18\x01 \x01(\tB\x1c\xf2\xc7\x31\x10[a-z][a-z0-9.-]*\x8a\xc8\x31\x04<=20\"\x8b\x01\n\x1bListPublicPrefixPoolRequest\x12\x11\n\tfolder_id\x18\x01 \x01(\t\x12\x1d\n\tpage_size\x18\x64 \x01(\x03\x42\n\xfa\xc7\x31\x06<=1000\x12\x12\n\npage_token\x18\x65 \x01(\t\x12\x10\n\x08order_by\x18\x66 \x01(\t\x12\x0e\n\x06\x66ilter\x18g \x01(\tJ\x04\x08\x02\x10\x64\"\x8c\x01\n\x1cListPublicPrefixPoolResponse\x12M\n\x13public_prefix_pools\x18\x01 \x03(\x0b\x32\x30.yandex.cloud.baremetal.v1alpha.PublicPrefixPool\x12\x17\n\x0fnext_page_token\x18\x64 \x01(\tJ\x04\x08\x02\x10\x64\"\xb4\x03\n\x1dUpdatePublicPrefixPoolRequest\x12;\n\x15public_prefix_pool_id\x18\x01 \x01(\tB\x1c\xf2\xc7\x31\x10[a-z][a-z0-9.-]*\x8a\xc8\x31\x04<=20\x12/\n\x0bupdate_mask\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.FieldMask\x12\x34\n\x04name\x18\x03 \x01(\tB&\xf2\xc7\x31\x1a[a-z]([-a-z0-9]*[a-z0-9])?\x8a\xc8\x31\x04\x32-63\x12\x1f\n\x0b\x64\x65scription\x18\x04 \x01(\tB\n\x8a\xc8\x31\x06<=1024\x12\x97\x01\n\x06labels\x18\xc8\x01 \x03(\x0b\x32I.yandex.cloud.baremetal.v1alpha.UpdatePublicPrefixPoolRequest.LabelsEntryB;\xf2\xc7\x31\x0b[-_0-9a-z]*\x82\xc8\x31\x04<=64\x8a\xc8\x31\x04<=63\xb2\xc8\x31\x18\x12\x10[a-z][-_0-9a-z]*\x1a\x04\x31-63\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01J\x05\x08\x05\x10\xc8\x01\"?\n\x1e\x43reatePublicPrefixPoolMetadata\x12\x1d\n\x15public_prefix_pool_id\x18\x01 \x01(\t\"?\n\x1eUpdatePublicPrefixPoolMetadata\x12\x1d\n\x15public_prefix_pool_id\x18\x01 \x01(\t\"?\n\x1e\x44\x65letePublicPrefixPoolMetadata\x12\x1d\n\x15public_prefix_pool_id\x18\x01 \x01(\t\"\x7f\n%ListPublicPrefixPoolOperationsRequest\x12\x1d\n\x15public_prefix_pool_id\x18\x01 \x01(\t\x12\x1d\n\tpage_size\x18\x64 \x01(\x03\x42\n\xfa\xc7\x31\x06<=1000\x12\x12\n\npage_token\x18\x65 \x01(\tJ\x04\x08\x02\x10\x64\"~\n&ListPublicPrefixPoolOperationsResponse\x12\x35\n\noperations\x18\x01 \x03(\x0b\x32!.yandex.cloud.operation.Operation\x12\x17\n\x0fnext_page_token\x18\x64 \x01(\tJ\x04\x08\x02\x10\x64\x32\xdf\x04\n\x17PublicPrefixPoolService\x12u\n\x03Get\x12:.yandex.cloud.baremetal.v1alpha.GetPublicPrefixPoolRequest\x1a\x30.yandex.cloud.baremetal.v1alpha.PublicPrefixPool\"\x00\x12\x83\x01\n\x04List\x12;.yandex.cloud.baremetal.v1alpha.ListPublicPrefixPoolRequest\x1a<.yandex.cloud.baremetal.v1alpha.ListPublicPrefixPoolResponse\"\x00\x12\xa2\x01\n\x06Update\x12=.yandex.cloud.baremetal.v1alpha.UpdatePublicPrefixPoolRequest\x1a!.yandex.cloud.operation.Operation\"6\xb2\xd2*2\n\x1eUpdatePublicPrefixPoolMetadata\x12\x10PublicPrefixPool\x12\xa1\x01\n\x0eListOperations\x12\x45.yandex.cloud.baremetal.v1alpha.ListPublicPrefixPoolOperationsRequest\x1a\x46.yandex.cloud.baremetal.v1alpha.ListPublicPrefixPoolOperationsResponse\"\x00\x42r\n\"yandex.cloud.api.baremetal.v1alphaZLgithub.com/yandex-cloud/go-genproto/yandex/cloud/baremetal/v1alpha;baremetalb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.baremetal.v1alpha.public_prefix_pool_service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\"yandex.cloud.api.baremetal.v1alphaZLgithub.com/yandex-cloud/go-genproto/yandex/cloud/baremetal/v1alpha;baremetal'
  _globals['_GETPUBLICPREFIXPOOLREQUEST'].fields_by_name['public_prefix_pool_id']._loaded_options = None
  _globals['_GETPUBLICPREFIXPOOLREQUEST'].fields_by_name['public_prefix_pool_id']._serialized_options = b'\362\3071\020[a-z][a-z0-9.-]*\212\3101\004<=20'
  _globals['_LISTPUBLICPREFIXPOOLREQUEST'].fields_by_name['page_size']._loaded_options = None
  _globals['_LISTPUBLICPREFIXPOOLREQUEST'].fields_by_name['page_size']._serialized_options = b'\372\3071\006<=1000'
  _globals['_UPDATEPUBLICPREFIXPOOLREQUEST_LABELSENTRY']._loaded_options = None
  _globals['_UPDATEPUBLICPREFIXPOOLREQUEST_LABELSENTRY']._serialized_options = b'8\001'
  _globals['_UPDATEPUBLICPREFIXPOOLREQUEST'].fields_by_name['public_prefix_pool_id']._loaded_options = None
  _globals['_UPDATEPUBLICPREFIXPOOLREQUEST'].fields_by_name['public_prefix_pool_id']._serialized_options = b'\362\3071\020[a-z][a-z0-9.-]*\212\3101\004<=20'
  _globals['_UPDATEPUBLICPREFIXPOOLREQUEST'].fields_by_name['name']._loaded_options = None
  _globals['_UPDATEPUBLICPREFIXPOOLREQUEST'].fields_by_name['name']._serialized_options = b'\362\3071\032[a-z]([-a-z0-9]*[a-z0-9])?\212\3101\0042-63'
  _globals['_UPDATEPUBLICPREFIXPOOLREQUEST'].fields_by_name['description']._loaded_options = None
  _globals['_UPDATEPUBLICPREFIXPOOLREQUEST'].fields_by_name['description']._serialized_options = b'\212\3101\006<=1024'
  _globals['_UPDATEPUBLICPREFIXPOOLREQUEST'].fields_by_name['labels']._loaded_options = None
  _globals['_UPDATEPUBLICPREFIXPOOLREQUEST'].fields_by_name['labels']._serialized_options = b'\362\3071\013[-_0-9a-z]*\202\3101\004<=64\212\3101\004<=63\262\3101\030\022\020[a-z][-_0-9a-z]*\032\0041-63'
  _globals['_LISTPUBLICPREFIXPOOLOPERATIONSREQUEST'].fields_by_name['page_size']._loaded_options = None
  _globals['_LISTPUBLICPREFIXPOOLOPERATIONSREQUEST'].fields_by_name['page_size']._serialized_options = b'\372\3071\006<=1000'
  _globals['_PUBLICPREFIXPOOLSERVICE'].methods_by_name['Update']._loaded_options = None
  _globals['_PUBLICPREFIXPOOLSERVICE'].methods_by_name['Update']._serialized_options = b'\262\322*2\n\036UpdatePublicPrefixPoolMetadata\022\020PublicPrefixPool'
  _globals['_GETPUBLICPREFIXPOOLREQUEST']._serialized_start=295
  _globals['_GETPUBLICPREFIXPOOLREQUEST']._serialized_end=384
  _globals['_LISTPUBLICPREFIXPOOLREQUEST']._serialized_start=387
  _globals['_LISTPUBLICPREFIXPOOLREQUEST']._serialized_end=526
  _globals['_LISTPUBLICPREFIXPOOLRESPONSE']._serialized_start=529
  _globals['_LISTPUBLICPREFIXPOOLRESPONSE']._serialized_end=669
  _globals['_UPDATEPUBLICPREFIXPOOLREQUEST']._serialized_start=672
  _globals['_UPDATEPUBLICPREFIXPOOLREQUEST']._serialized_end=1108
  _globals['_UPDATEPUBLICPREFIXPOOLREQUEST_LABELSENTRY']._serialized_start=1056
  _globals['_UPDATEPUBLICPREFIXPOOLREQUEST_LABELSENTRY']._serialized_end=1101
  _globals['_CREATEPUBLICPREFIXPOOLMETADATA']._serialized_start=1110
  _globals['_CREATEPUBLICPREFIXPOOLMETADATA']._serialized_end=1173
  _globals['_UPDATEPUBLICPREFIXPOOLMETADATA']._serialized_start=1175
  _globals['_UPDATEPUBLICPREFIXPOOLMETADATA']._serialized_end=1238
  _globals['_DELETEPUBLICPREFIXPOOLMETADATA']._serialized_start=1240
  _globals['_DELETEPUBLICPREFIXPOOLMETADATA']._serialized_end=1303
  _globals['_LISTPUBLICPREFIXPOOLOPERATIONSREQUEST']._serialized_start=1305
  _globals['_LISTPUBLICPREFIXPOOLOPERATIONSREQUEST']._serialized_end=1432
  _globals['_LISTPUBLICPREFIXPOOLOPERATIONSRESPONSE']._serialized_start=1434
  _globals['_LISTPUBLICPREFIXPOOLOPERATIONSRESPONSE']._serialized_end=1560
  _globals['_PUBLICPREFIXPOOLSERVICE']._serialized_start=1563
  _globals['_PUBLICPREFIXPOOLSERVICE']._serialized_end=2170
# @@protoc_insertion_point(module_scope)
